# Changelog

<!--next-version-placeholder-->

## v0.3.0 (2020-12-02)
### Feature
* Avoid line-wrapping paths ([`65c0149`](https://github.com/kalekundert/tidyexc/commit/65c014999026b95c12f0d30665f2d9a8c54ad4c0))

### Documentation
* Write documentation ([`04b79f7`](https://github.com/kalekundert/tidyexc/commit/04b79f7bfa7238ddbf18f357475b9f4897a0696a))

## v0.2.0 (2020-11-30)
### Feature
* Make the stack functions class methods ([`bf93c60`](https://github.com/kalekundert/tidyexc/commit/bf93c6084c3f33895cc2b28e1ef17c7c3fce0e18))
